ParseErrorKind

Enum ParseErrorKind 

#[non_exhaustive]
pub enum ParseErrorKind { UnexpectedChar, UnexpectedToken { found: String, expected: Vec<String>, }, UnterminatedString, UnterminatedBlockComment, InvalidNumericLiteral, InvalidParameter, UnexpectedEof { expected: Vec<String>, }, }
The kind of parse error.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnexpectedChar

The lexer encountered a byte sequence it could not tokenize.



UnexpectedToken

The parser encountered a token that does not fit the grammar at this position.

Fields

found: String

What was found.

expected: Vec<String>

What the parser expected (human-readable).



UnterminatedString

A string literal was opened but never closed.



UnterminatedBlockComment

A block comment was opened with /* but never closed with */.



InvalidNumericLiteral

An integer or float literal could not be parsed.



InvalidParameter

A $ parameter prefix was not followed by a valid name or index.



UnexpectedEof

A query ended before it was syntactically complete.

Fields

expected: Vec<String>

What the parser expected at end of input.